@@ -88,43 +88,43 @@ class PageAdvanced (PageMenu, FormHelper):
         self.AddPropEntry (table, _('Max keepalive reqs'), 'server!keepalive_max_requests', _(NOTE_KEEPALIVE_RS))
         self.AddPropCheck (table, _('Chunked Encoding'),   'server!chunked_encoding', True, _(NOTE_CHUNKED))
         self.AddPropOptions_Reload_Plain (table, _('Polling Method'), 'server!poll_method',  polling_methods, _(NOTE_POLLING))
-        self.AddPropEntry (table, _('Sendfile min size'),  'server!sendfile_min', _(NOTE_SENDFILE_MIN))
-        self.AddPropEntry (table, _('Sendfile max size'),  'server!sendfile_max', _(NOTE_SENDFILE_MAX))
+        self.AddPropEntry (table, _('Sendfile min size'),  'server!sendfile_min', _(NOTE_SENDFILE_MIN), optional=True)
+        self.AddPropEntry (table, _('Sendfile max size'),  'server!sendfile_max', _(NOTE_SENDFILE_MAX), optional=True)
         return self.Indent(table)
 
     def _render_resources (self):
         table = TableProps()
-        self.AddPropEntry (table, _('Thread Number'),          'server!thread_number',        _(NOTE_THREAD_NUM))
+        self.AddPropEntry (table, _('Thread Number'),          'server!thread_number',        _(NOTE_THREAD_NUM), optional=True)
         self.AddPropOptions_Reload_Plain (table, _('Thread Policy'), 'server!thread_policy', THREAD_POLICY, _(NOTE_THREAD))
-        self.AddPropEntry (table, _('File descriptors'),       'server!fdlimit',              _(NOTE_FD_NUM))
-        self.AddPropEntry (table, _('Listening queue length'), 'server!listen_queue',         _(NOTE_LISTEN_Q))
-        self.AddPropEntry (table, _('Reuse connections'),      'server!max_connection_reuse', _(NOTE_REUSE_CONNS))
-        self.AddPropEntry (table, _('Log flush time'),         'server!log_flush_lapse',     _(NOTE_FLUSH_TIME))
-        self.AddPropEntry (table, _('Nonces clean up time'),   'server!nonces_cleanup_lapse',_(NOTE_NONCES_TIME))
+        self.AddPropEntry (table, _('File descriptors'),       'server!fdlimit',              _(NOTE_FD_NUM), optional=True)
+        self.AddPropEntry (table, _('Listening queue length'), 'server!listen_queue',         _(NOTE_LISTEN_Q), optional=True)
+        self.AddPropEntry (table, _('Reuse connections'),      'server!max_connection_reuse', _(NOTE_REUSE_CONNS), optional=True)
+        self.AddPropEntry (table, _('Log flush time'),         'server!log_flush_lapse',     _(NOTE_FLUSH_TIME), optional=True)
+        self.AddPropEntry (table, _('Nonces clean up time'),   'server!nonces_cleanup_lapse',_(NOTE_NONCES_TIME), optional=True)
         return self.Indent(table)
 
     def _render_iocache (self):
         table = TableProps()
         self.AddPropCheck (table, _('Status'),        'server!iocache', True,         _(NOTE_IO_ENABLED))
-        self.AddPropEntry (table, _('Max pages'),     'server!iocache!max_size',      _(NOTE_IO_SIZE))
-        self.AddPropEntry (table, _('File Min Size'), 'server!iocache!min_file_size', _(NOTE_IO_MIN_SIZE))
-        self.AddPropEntry (table, _('File Max Size'), 'server!iocache!max_file_size', _(NOTE_IO_MAX_SIZE))
-        self.AddPropEntry (table, _('Lasting: stat'), 'server!iocache!lasting_stat',  _(NOTE_IO_LAST_STAT))
-        self.AddPropEntry (table, _('Lasting: mmap'), 'server!iocache!lasting_mmap',  _(NOTE_IO_LAST_MMAP))
+        self.AddPropEntry (table, _('Max pages'),     'server!iocache!max_size',      _(NOTE_IO_SIZE), optional=True)
+        self.AddPropEntry (table, _('File Min Size'), 'server!iocache!min_file_size', _(NOTE_IO_MIN_SIZE), optional=True)
+        self.AddPropEntry (table, _('File Max Size'), 'server!iocache!max_file_size', _(NOTE_IO_MAX_SIZE), optional=True)
+        self.AddPropEntry (table, _('Lasting: stat'), 'server!iocache!lasting_stat',  _(NOTE_IO_LAST_STAT), optional=True)
+        self.AddPropEntry (table, _('Lasting: mmap'), 'server!iocache!lasting_mmap',  _(NOTE_IO_LAST_MMAP), optional=True)
         return self.Indent(table)
 
     def _render_special_files (self):
         table = TableProps()
-        self.AddPropEntry (table, _('Panic action'), 'server!panic_action', _(NOTE_PANIC_ACTION))
-        self.AddPropEntry (table, _('PID file'),     'server!pid_file',     _(NOTE_PID_FILE))
+        self.AddPropEntry (table, _('Panic action'), 'server!panic_action', _(NOTE_PANIC_ACTION), optional=True)
+        self.AddPropEntry (table, _('PID file'),     'server!pid_file',     _(NOTE_PID_FILE), optional=True)
         return self.Indent(table)
 
     def _render_tls (self):
 	table = TableProps()
-        self.AddPropEntry (table, _('DH parameters: 512 bits'), 'server!tls!dh_param512', _(NOTE_DH512))
-        self.AddPropEntry (table, _('DH parameters: 1024 bits'), 'server!tls!dh_param1024', _(NOTE_DH1024))
-        self.AddPropEntry (table, _('DH parameters: 2048 bits'), 'server!tls!dh_param2048', _(NOTE_DH2048))
-        self.AddPropEntry (table, _('DH parameters: 4096 bits'), 'server!tls!dh_param4096', _(NOTE_DH4096))
+        self.AddPropEntry (table, _('DH parameters: 512 bits'), 'server!tls!dh_param512', _(NOTE_DH512), optional=True)
+        self.AddPropEntry (table, _('DH parameters: 1024 bits'), 'server!tls!dh_param1024', _(NOTE_DH1024), optional=True)
+        self.AddPropEntry (table, _('DH parameters: 2048 bits'), 'server!tls!dh_param2048', _(NOTE_DH2048), optional=True)
+        self.AddPropEntry (table, _('DH parameters: 4096 bits'), 'server!tls!dh_param4096', _(NOTE_DH4096), optional=True)
         return self.Indent(table)
 
     def _render_content (self):
