@@ -202,10 +202,10 @@ config_server (cherokee_server_t *srv)
 					 "source!1!timeout = 25\n"
 					 "source!1!host = %s\n"
 					 "source!1!interpreter = %s/server.py %s %s\n"
-					 "source!1!env!PATH = %s\n",
+					 "source!1!env_inherited = 1\n",
 					 DEFAULT_UNIX_SOCKET, document_root,
-					 DEFAULT_UNIX_SOCKET,
-					 config_file, getenv("PATH"));
+					 DEFAULT_UNIX_SOCKET, config_file);
+					 
 	} else {
 		cherokee_buffer_add_va  (&buf,
 					 "source!1!nick = app-logic\n"
@@ -213,9 +213,8 @@ config_server (cherokee_server_t *srv)
 					 "source!1!timeout = 25\n"
 					 "source!1!host = localhost:%d\n"
 					 "source!1!interpreter = %s/server.py %d %s\n"
-					 "source!1!env!PATH = %s\n",
-					 scgi_port, document_root, scgi_port, 
-					 config_file, getenv("PATH"));
+					 "source!1!env_inherited = 1\n",
+					 scgi_port, document_root, scgi_port, config_file);
 	}
 
 	if (debug) {
