@@ -23,7 +23,7 @@ class Test (TestBase):
         self.request           = "GET /%s/Range100b2 HTTP/1.0\r\n" % (DIR) +\
                                  "Range: bytes=-%d\r\n" % (OFFSET)
         self.expected_error    = 206
-        self.expected_content  = [MAGIC[:OFFSET], "Content-Length: %d" % (OFFSET + 1)]
+        self.expected_content  = [MAGIC[:OFFSET], "Content-Length: %d" % (OFFSET)]
         self.forbidden_content = MAGIC[OFFSET:]
 
     def Prepare (self, www):
